/* _NVRM_COPYRIGHT_BEGIN_
 *
 * Copyright 1999-2001 by NVIDIA Corporation.  All rights reserved.  All
 * information contained herein is proprietary and confidential to NVIDIA
 * Corporation.  Any use, reproduction, or disclosure without the written
 * permission of NVIDIA Corporation is prohibited.
 *
 * _NVRM_COPYRIGHT_END_
 */


#ifndef _NV_H_
#define _NV_H_

/* Nvidia's reserved major device number
 * Set this to 0 to request dynamic major number allocation. */
#define NV_MAJOR_DEVICE_NUMBER 195

/* most cards in a single system */
#define NV_MAX_DEVICES 8

#ifdef __KERNEL__

typedef unsigned char  V008;
typedef unsigned short V016;
typedef unsigned int   V032;
typedef unsigned int   U032;

/*
 * ptr arithmetic convenience
 */

typedef union
{
    volatile V008 Reg008[1];
    volatile V016 Reg016[1];
    volatile V032 Reg032[1];
} nv_hwreg_t, * nv_phwreg_t;

typedef struct {
    U032 address;
    U032 size;
    U032 *map;
    nv_phwreg_t map_u;
} nv_aperture_t;


typedef struct {
    nv_aperture_t regs;
    nv_aperture_t fb;
} nv_bar_t;


/*
 * per device state
 */

typedef struct
{
    void  *pdev;                    /* you know who */
    void  *priv;                    /* private data */
    void  *os_state;                /* os-specific version of this file */

    int    rmInitialized;
    int    flags;
    int    device_number;

    /* mapped addresses */
    U032 *rom;

    /* PCI config info */
    int bus;
    int slot;
    int vendor_id;
    int device_id;

    /* physical characteristics */
    nv_bar_t bar;
    nv_aperture_t *regs;
    nv_aperture_t *fb;
    nv_aperture_t agp;

    U032 interrupt_line;

    U032 agp_config;

    /* save/restore eflags register */
    unsigned long saved_eflags;

    U032 sim_env;

    U032 rc_timer_enabled;

} nv_state_t;


/*
 * driver internal interfaces
 */

/* need a fake device number for control device; just to flag it for msgs */
#define NV_CONTROL_DEVICE_NUMBER     100

#endif /* __KERNEL__ */

#endif
